@@ -1,8 +1,8 @@
 import json
 import sys
-
 import requests
 from datetime import datetime
+
 import pkg_resources
 
 from logger.src.common.configuration.httpClientConfig import HttpClientConfig
@@ -10,36 +10,36 @@ from logger.src.common.dto.payload import Payload
 from logger.src.common.dto.payloadDetail import PayloadDetail
 from logger.src.common.dto.payloadDetailMetadata import PayloadDetailMetadata
 from logger.src.common.dto.payloadDetailSdk import PayloadDetailSdk
-
 from logger.src.common.enums.logLevel import LogLevel
+from logger.src.version import __version__
 
 with requests.Session() as session:
     session.headers.update({
         'Content-Type': 'application/json',
     })
 
-    apiKey = None
-    userInfo = None
+    user_api_key = None
+    user_info = None
     tags = []
 
     def set_api_key(api_key):
-        apiKey = api_key
+        user_api_key = api_key
 
         session.headers.update({
-            'Authorization': f'X-API-KEY {apiKey}'
+            'Authorization': f'X-API-KEY {user_api_key}'
         })
 
     def set_user(user):
-        userInfo = user
+        user_info = user
 
     def set_tag(property_name, property_value):
-        tags.insert({property_name: property_value})
+        tags.append({property_name: property_value})
 
-    def info(message, eventTimeRequired = False):
+    def info(message, event_time_required = False):
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
         print('installed_packages => ', installed_packages)
 
-        eventTime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S") if eventTimeRequired else None
+        eventTime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S") if event_time_required else None
         print('eventTime => ', eventTime)
 
         sourceFilePath = sys._getframe().f_code
@@ -48,8 +48,8 @@ with requests.Session() as session:
         methodName = sys._getframe(1).f_code.co_name
         print('methodName => ', methodName)
 
-        version = pkg_resources.get_distribution('alertnow-python')[0].version
-        print('version => ', version)
+        print('version => ', __version__)
+
         detail = [
             PayloadDetail(
                 LogLevel.info,
@@ -60,7 +60,7 @@ with requests.Session() as session:
                 None,
                 message,
                 LogLevel.info,
-                version,
+                __version__,
                 PayloadDetailMetadata(
                     sourceFilePath,
                     methodName,
@@ -68,7 +68,7 @@ with requests.Session() as session:
                     message
                 ),
                 PayloadDetailSdk(
-                    version,
+                    __version__,
                     installed_packages
                 )
             )
@@ -82,13 +82,13 @@ with requests.Session() as session:
             json.dumps(vars(detail))
         ))
 
-    def error(occurred_error):
+    def error(occurred_error, event_time_required = False):
         message = json.dumps(vars(occurred_error))
 
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
         print('installed_packages => ', installed_packages)
 
-        eventTime = eventTimeRequired if datetime.now().strftime("%m/%d/%Y, %H:%M:%S") else None
+        eventTime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S") if event_time_required else None
         print('eventTime => ', eventTime)
 
         sourceFilePath = sys._getframe().f_code
@@ -97,8 +97,8 @@ with requests.Session() as session:
         methodName = sys._getframe(1).f_code.co_name
         print('methodName => ', methodName)
 
-        version = pkg_resources.require('alertnow-phyton')[0].version
-        print('version => ', version)
+        print('version => ', __version__)
+
         detail = [
             PayloadDetail(
                 LogLevel.error,
@@ -109,7 +109,7 @@ with requests.Session() as session:
                 None,
                 message,
                 LogLevel.error,
-                version,
+                __version__,
                 PayloadDetailMetadata(
                     sourceFilePath,
                     methodName,
@@ -117,7 +117,7 @@ with requests.Session() as session:
                     message
                 ),
                 PayloadDetailSdk(
-                    version,
+                    __version__,
                     installed_packages
                 )
             )
@@ -132,6 +132,6 @@ with requests.Session() as session:
         ))
 
     def create_log(payload):
-        response = session.post(f'{HttpClientConfig.alertNowURL}/integration/appinsight/v1/{apiKey}',
+        response = session.post(f'{HttpClientConfig.alertNowURL}/integration/appinsight/v1/{user_api_key}',
                                 data=json.dumps(vars(payload)))
         return response
